@@ -16,10 +16,7 @@
  * along with Conboy. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
+#include "localisation.h"
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -31,6 +28,7 @@
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 #include <gdk/gdkkeysyms.h>
+#include <glib.h>
 #include <math.h>
 
 #include "callbacks.h"
@@ -43,8 +41,6 @@
 #include "note_linker.h"
 #include "app_data.h"
 
-#define _(String)gettext(String)
-
 
 /* Private. TODO: Move to some public file */
 GtkTextTag* iter_get_depth_tag(GtkTextIter* iter);
@@ -1064,7 +1060,6 @@ gboolean tag_is_depth_tag(GtkTextTag *tag)
 	return (strncmp(tag->name, "depth", 5) == 0);
 }
 
-
 gint tag_get_depth(GtkTextTag *tag)
 {
 	if (tag_is_depth_tag(tag)) {
