@@ -16,51 +16,20 @@
  * along with Conboy. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "localisation.h"
 
-/* Includes */
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
 #include <hildon/hildon-program.h>
-#include <hildon/hildon-window.h>
 #include <gtk/gtkmain.h>
-#include <glib/gstdio.h>
-#include <gconf/gconf.h>
-#include <gconf/gconf-client.h>
 #include <libosso.h>
-#include <string.h>
-#include <stdlib.h>
 
-#include <libxml/xmlreader.h>
-
-#include <libxml/encoding.h>
-#include <libxml/xmlwriter.h>
-
-#include <stdio.h>
-
-#include <libintl.h>
-#include <locale.h>
-
-#ifndef __USE_XOPEN
-#define __USE_XOPEN
-#endif
-#include <time.h>
-
-#include "metadata.h"
-#include "interface.h"
-#include "callbacks.h"
-#include "note.h"
 #include "app_data.h"
-
-#include "search_window.h"
-#include "note_list_store.h"
+/*#include "json.h"*/
 
 
 #define APP_NAME "conboy"
 #define APP_SERVICE "de.zwong.conboy"
 #define APP_METHOD "/de/zwong/conboy"
 
-#define MY_ENCODING "utf-8"
 
 static void cleanup()
 {
@@ -89,10 +58,7 @@ main (int argc, char *argv[])
   AppData *app_data;
 
   /* Init i18n */
-  setlocale(LC_ALL, "");
-  bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
-  bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
-  textdomain(GETTEXT_PACKAGE);
+  locale_init();
   
   /* Init GTK */
 #ifdef HILDON_HAS_APP_MENU
@@ -125,7 +91,26 @@ main (int argc, char *argv[])
   }
 
   note_show(note);
-
+  
+  /*******/
+  /*
+  print_note_as_json(note);
+  JsonNode *node = get_json_object_from_note(note);
+  Note *xnote = get_note_from_json_object(node);
+  g_printerr("### %s \n", xnote->guid);
+  g_printerr("### %s \n", xnote->title);
+  g_printerr("### %f \n", xnote->content_version);
+  g_printerr("### %f \n", xnote->version);
+  g_printerr("### %i \n", xnote->last_change_date);
+  
+  GList *tags = note->tags;
+  while (tags != NULL) {
+	  g_printerr("TAG %s \n", (gchar*)tags->data);
+	  tags = tags->next;
+  }
+  */
+  /*********/
+  
   gtk_main();
 
   cleanup();
