@@ -67,9 +67,14 @@ typedef struct
   gint x;
   gint y;
   gboolean open_on_startup;
-  gchar *version;
+  double version;
+  double content_version;
 
-  GSList *active_tags;
+  gchar *guid;
+  GList *tags; /* Tags aka notebooks */
+  
+  GSList *active_tags; /* TODO: This shouldn't really be part of this structure, more UI, because it is never written to disk */
+  
 
 } Note;
 
@@ -112,4 +117,6 @@ void note_add_active_tag_by_name(Note *note, const gchar *tag_name);
 
 void note_remove_active_tag_by_name(Note *note, const gchar *tag_name);
 
+void note_add_tag(Note *note, gchar *tag);
+
 #endif /* NOTE_H */
