@@ -15,9 +15,7 @@
  * You should have received a copy of the GNU General Public License
  * along with Conboy. If not, see <http://www.gnu.org/licenses/>.
  */
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+#include "localisation.h"
 
 #include <gtk/gtk.h>
 #include <hildon/hildon-window.h>
@@ -37,8 +35,6 @@
 #include "note.h"
 #include "note_list_store.h"
 
-#define _(String)gettext(String)
-
 static gboolean
 is_row_visible(GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 {
